require(randomForest)
load(file="x_data.RData"); load(file="y_data.RData")

##########
##  Random Forest regression of population density:
set.seed(2002)

##  Now we are going tune our randomForest population density regression: 
init_popfit = tuneRF(
  x=x_data, y=y_data, plot=TRUE, mtryStart=length(x_data)/3, 
  ntreeTry=length(y_data)/20, improve=0.0001, stepFactor=1.20, trace=TRUE,
  doBest=TRUE, nodesize=length(y_data)/1000, na.action=na.omit, 
  importance=TRUE, proximity=TRUE, sampsize=length(y_data), replace=TRUE
) 


##  Save the init_popfit object for this set of data:
save(init_popfit, file=paste(output_path_tmp, "init_popfit.RData", sep=""))


##  Optimize the model by iteratively removing any 
##    covariates with negative increases in node purity:

##  Get list of covariates that have an importance score greater than 0:
importance_scores <- 
  importance(init_popfit)[order(importance(init_popfit)[,1], decreasing=TRUE),]
pos_importance <- rownames(importance_scores)[importance_scores[,1] > 0]

while (length(pos_importance) < length(importance_scores[,1])) {
  
  ## Subset the x_data to just those columns having positive scores:
  x_data <- x_data[pos_importance]
  popfit = tuneRF(
    x=x_data, y=y_data, plot=TRUE, mtryStart=length(x_data)/3, 
    ntreeTry=length(y_data)/20, improve=0.0001, stepFactor=1.20, trace=TRUE, 
    doBest=TRUE, nodesize=length(y_data)/1000, na.action=na.omit, 
    importance=TRUE, proximity=TRUE, sampsize=length(y_data), replace=TRUE
  ) 
  
  ## Re-check importance scores:
  importance_scores <- importance(popfit)[order(importance(popfit)[,1], decreasing=TRUE),]
  pos_importance <- rownames(importance_scores)[importance_scores[,1] > 0]
  print(popfit)

}


##  Save off the popfit object for this set of data and potentially use
##    for other countries with the same available covariates:
save(popfit, file=paste(output_path_tmp, "popfit.RData", sep=""))
